@@ -5,7 +5,7 @@ use warnings;
 
 package Net::Fritz::Service;
 # ABSTRACT: represents a TR064 service
-$Net::Fritz::Service::VERSION = 'v0.0.3';
+$Net::Fritz::Service::VERSION = 'v0.0.4';
 
 use Digest::MD5 qw(md5_hex);
 use SOAP::Lite; # +trace => [ transport => sub { print $_[0]->as_string } ]; # TODO: remove
@@ -148,10 +148,12 @@ sub call {
     my $url = $self->fritz->upnp_url . $self->controlURL;
 
     my $soap = SOAP::Lite->new(
-	proxy    => [ $url, ssl_opts => $self->fritz->_sslopts ],
+	proxy    => [ $url, ssl_opts => $self->fritz->_sslopts, keep_alive => 1, ],
 	uri      => $self->serviceType,
 	readable => 1, # TODO: remove this
 	);
+    # Keep up to 4 connections open
+    $soap->transport->conn_cache({ total_capacity => 4 });
 
     # expect the call to need authentication, so prepare an initial request
     my $auth = $self->_get_initial_auth;
@@ -316,7 +318,7 @@ Net::Fritz::Service - represents a TR064 service
 
 =head1 VERSION
 
-version v0.0.3
+version v0.0.4
 
 =head1 SYNOPSIS
 
@@ -381,7 +383,7 @@ L</call> any L<Net::Fritz::Action>s of this service.
 The I<eventSubURL> (URL string) of this service for subscribing to or
 unsubscribing from events.
 
-=head2
+=head2 SCPDURL
 
 The I<SCPDURL> (URL string) of the SCPD file of this service where
 most of the other attributes are read from.
@@ -445,7 +447,7 @@ Christian Garbs <mitch@cgarbs.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 Christian Garbs
+Copyright (C) 2017 Christian Garbs
 
 This program is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the Free
